Changes
=======

1.0.1 (2012-05-10)
------------------

- Quote URLs passed to the "Enqueue" action.

- Added support for HEAD request.

- Use ``gzip`` library to correctly read and decompress
  zlib-compressed responses.

1.0 (2012-05-10)
----------------

- Initial public release.
